\NeedsTeXFormat{LaTeX2e}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{scrbook}}
\ProcessOptions\relax
\LoadClass{scrbook}
\ProvidesClass{skript}

\RequirePackage{tikz}
\usetikzlibrary{babel}
\RequirePackage{tikz-cd}
\tikzcdset{arrow style=tikz, diagrams={>=stealth}}

\RequirePackage{polyglossia}
\setdefaultlanguage{german}

\RequirePackage{csquotes}
\RequirePackage{hyphenat}
\RequirePackage{titlesec}

\RequirePackage{gitinfo}
\RequirePackage{mathtools}
\RequirePackage{amsmath, amssymb}

% fonts
\RequirePackage[warnings-off={mathtools-colon,mathtools-overbracket}]{unicode-math}
\setromanfont[Ligatures=TeX]{TeX Gyre Pagella}
\setsansfont{Latin Modern Sans}
% \setsansfont{Roboto}
% \setmathfont{XITS Math}
\setmathfont{TeX Gyre Pagella Math}
\setmathfont[range=\setminus]{XITS Math}
\setmathfont[range={\sum}]{TeX Gyre Termes Math}
\setmathfont[range={\int}]{XITS Math}
\setmathfont{Latin Modern Math}[range={cal,bfcal},StylisticSet=1]
% \setmathfont[range={\mathcal}]{Latin Modern Math}
\setkomafont{disposition}{\sffamily}

\RequirePackage{mathtools}
\RequirePackage{amsmath, amsfonts, amssymb}


% fonts
\RequirePackage{textcomp}                % für erweiterten Text-Symbolvorrat
\setkomafont{disposition}{\sffamily}
\RequirePackage{setspace}
\setstretch{1.10}
\setlength\parskip{4pt}
\setlength\parindent{0pt}

\RequirePackage[amsmath, thmmarks, framed]{ntheorem}
\RequirePackage[framemethod=tikz]{mdframed}
\RequirePackage{versions}

\RequirePackage{hyperref}
\RequirePackage[capitalise, nameinlink]{cleveref}

\RequirePackage{scrpage2}
\RequirePackage{authoraftertitle}

\pagestyle{scrheadings}
\clearscrheadfoot
\ohead{\headmark}
\cfoot{-- \pagemark~--}
\automark{section}

\usepackage{enumitem}
\setenumerate{label=(\alph*)}

\makeatletter
\makeatletter 
 \newtheoremstyle{mychange}%
  {\item[\hskip\labelsep \theorem@headerfont (##2)\ ##1\theorem@separator]}%
  {\item[\hskip\labelsep \theorem@headerfont (##2)\ ##1\ (##3)\theorem@separator]}
 \newtheoremstyle{nonumbermychange}%
  {\item[\hskip\labelsep \theorem@headerfont ##1\theorem@separator]}%
  {\item[\hskip\labelsep \theorem@headerfont ##1\ (##3)\theorem@separator]}
\makeatother
\DeclareDocumentCommand\newmdtheoremenv{s O{} m o m o }{%
\IfBooleanTF{#1}{%
   \newtheorem*{#3}{#5}%
 }{%
 \ifboolexpr{ test {\IfNoValueTF {#4}} and test {\IfNoValueTF {#6}} }%
    {\newtheorem{#3}{#5}}{%
     \IfValueTF{#4}{\newtheorem{#3}[#4]{#5}}{}%
     \IfValueTF{#6}{\newtheorem{#3}{#5}[#6]}{}%
    }
  }%
  \BeforeBeginEnvironment{#3}{%
     \begin{mdframed}[#2]}%
  \AfterEndEnvironment{#3}{%
     \end{mdframed}}%
}
\newcounter{defsatzusw}
\def\newthm#1#2{
    \newmdtheoremenv[ntheorem,
    linewidth=0.5pt,
    backgroundcolor=black!05,
    linecolor=black,
    everyline=true,
    leftline=true, rightline=true, bottomline=true, topline=true,
    ]{#1}[defsatzusw]{#2}
    \newmdtheoremenv*[ntheorem,
    linewidth=0.5pt,
    backgroundcolor=black!05,
    linecolor=black,
    everyline=true,
    leftline=true, rightline=true, bottomline=true, topline=true,
    ]{#1-nn}{#2}
}
\def\newdef#1#2{\newtheorem{#1}[defsatzusw]{#2}\newtheorem*{#1-nn}{#2}}
\theoremseparator{.}
\numberwithin{defsatzusw}{section}
% \theoremsymbol{\ensuremath{\diamond}}
% kursive schrift
\theoremstyle{mychange}
\newthm{satz}{Satz}
\newthm{lemma}{Lemma}
\newthm{korollar}{Korollar}
\newthm{folgerung}{Folgerung}
\newthm{hilfssatz}{Hilfssatz}
\newthm{proposition}{Proposition}
% aufrechte schrift
\theorembodyfont{\normalfont}
\newthm{definition}{Definition}
\newthm{bezeichnung}{Bezeichnung}
\newthm{bezeichnungen}{Bezeichnungen}
\newthm{voraussetzung}{Voraussetzung}
\newthm{voraussetzungen}{Voraussetzungen}
\newdef{bemerkung}{Bemerkung}
\newdef{bemerkungen}{Bemerkungen}
\newdef{erinnerung}{Erinnerung}
\newdef{beispiel}{Beispiel}
\newdef{beispiele}{Beispiele}
\newdef{problem}{Problem}

\theoremstyle{nonumberplain}
\theoremheaderfont{\bfseries}
\theorembodyfont{\normalfont}
\theoremseparator{.}
% \theoremsymbol{\scalebox{0.8}{\ensuremath{\blacksquare}}}
\theoremsymbol{\ensuremath\square}
\newtheorem{proof}{Beweis}
\newtheorem{beweis}{Beweis}

\titleformat{\section}{\titlefont\Large}%
 {\S\,\thesection}{.66em}{}
\renewcommand{\thesection}{\arabic{section}}

\endinput